/*
Gwenview - A simple image viewer for TDE
Copyright 2006 Aurélien Gâteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
#ifndef BCGDIALOG_H
#define BCGDIALOG_H

// KDE
#include <kdialogbase.h>

class TQShowEvent;

namespace Gwenview {

class ImageView;

class BCGDialog : public KDialogBase {
TQ_OBJECT
  
public:
	BCGDialog(ImageView*);
	~BCGDialog();

protected:
	virtual void slotDefault();

private slots:
	void updateFromImageView();

private:
	struct Private;
	Private* d;
};


} // namespace

#endif /* BCGDIALOG_H */
